@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -46,8 +46,7 @@ ContactConfigureDialog::ContactConfigureDialog(QWidget *parent)
     QTabWidget *tab = new QTabWidget;
 
     QWidget *w = new QWidget;
-    QVBoxLayout *lay = new QVBoxLayout;
-    w->setLayout(lay);
+    QVBoxLayout *lay = new QVBoxLayout(w);
 
     mConfigureWidget = new GrantleeThemeEditor::ConfigureWidget;
     lay->addWidget(mConfigureWidget);
